#!/bin/bash

# spdx-license-identifier: gpl-3.0-only
# Copyright (C) 2022 Michał Góral

[[ -n "${LIBGPAK_BUILD_DOCKER_SH:-}" ]] && return
LIBGPAK_BUILD_DOCKER_SH=1

source "${LIBRARY}/message.sh"
source "${LIBRARY}/spinner.sh"

gen_docker() {
    local infile="$1"
    local outfile="$2"
    local distribution="$3"
}

build_docker() {
    local codename="$1"
    local outcontext="${BUILD_DIR}/${codename}/.docker"
    local tag="gpak:${codename}"
    local flags=(--tag "${tag}")

    if [[ -e "${outcontext}/Dockerfile" ]]; then
        msg2 "Reusing existing Docker context: %s" "${outcontext}"
    else
        msg2 "Generating new Docker context from a template: %s" "${outcontext}"

        rm -rf "${outcontext}"
        mkdir -p "$(dirname -- "${outcontext}")"
        cp -r "${DOCKER_CONTEXT}" "${outcontext}"

        shopt -s globstar nullglob
        echo "${outcontext}"/**/*.in
        for infile in "${outcontext}"/**/*.in; do
            msg2 "Generating %s -> %s" "${infile}" "${infile%.in}"

            sed -i \
                -e "s|@CODENAME[@]|${codename}|g" \
                "$infile"
            mv "${infile}" "${infile%.in}"
        done
        shopt -u globstar nullglob

        flags+=(--no-cache)
    fi

    docker build "${outcontext}" "${flags[@]}"
}

build_docker_images() {
    for codename in "$@"; do
        spinmsg "Building %s docker image" "${codename}"
        spinner build_docker "$codename"
        [[ $? -ne 0 ]] && return 1
    done
    return 0
}
