#!/bin/bash

# spdx-license-identifier: gpl-3.0-only
# Copyright (C) 2022 Michał Góral

[[ -n "${LIBGPAK_SEND_SH:-}" ]] && return
LIBGPAK_SEND_SH=1

source "${LIBRARY}/message.sh"
source "${LIBRARY}/exit_codes.sh"

send_distro_packages() {
    local distro="$1" ; shift
    local component="$1" ; shift
    local packages=("$@")

    local source_dir="${BUILD_DIR}/${distro}"

    msg "Sending packages: distro=%s component=%s" "$distro" "$component"

    debs=()
    shopt -s globstar nullglob
    for pkg in "${packages[@]}"; do
        debs+=("${source_dir}/${pkg}/"*.deb)
    done
    shopt -u globstar nullglob

    if [[ ${#debs} -eq 0 ]]; then
        error2 "No debs found in '%s'." "${source_dir}" >&2
        return $E_ERROR
    fi

    remote_dest="${REMOTE_PATH}/${distro}-${component}/"

    # TODO: with a lot of debs, argument list might grow too big. In that case
    # we would like to use sth like that:
    #
    #    printf "%s\n" "${debs[@]}" | \
    #        sort | \
    #        rsync --dry-run -vz --files-from=- / "${remote_dest}"
    #
    # One problem is, however, that rsync still requires both SRC and DST (/
    # and ${remote_dest} here). All files must be relative to SRC and SRC's
    # structure will be recreated on DST. However, we store packages in
    # .build/bullseye/<pkg>/*.deb.
    #
    # If we stored them in .build/bullseye-main/*.deb, then using rsync would be
    # easier. Additionally, a single rsync could be run for all distros.
    #
    # How to achieve it? Hardlinks?
    rsync -rz "${debs[@]}" "${remote_dest}"
}

send_packages() {
    component="$1"; shift
    packages=("$@")
    local ret=0

    for distro in "${DISTRIBUTIONS[@]}"; do
        send_distro_packages "${distro}" "${component}" "${packages[@]}"
        [[ $? -ne 0 ]] && ret=$E_SEND_ERROR
        # TODO: configurable (disablable? enablable?) cleanup step
    done

    return $ret
}
